import * as Types from './schemas';
import { GraphQLClient } from 'graphql-request';
import * as Dom from 'graphql-request/dist/types.dom';
export declare type Maybe<T> = T | null;
export declare type InputMaybe<T> = Maybe<T>;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    Any: any;
    Int64: any;
    Timestamp: any;
};
export declare type BackendErrorObjectInput = {
    event: Scalars['String'];
    payload?: InputMaybe<Scalars['String']>;
    request_id: Scalars['String'];
    session_secure_id: Scalars['String'];
    source: Scalars['String'];
    stackTrace: Scalars['String'];
    timestamp: Scalars['Timestamp'];
    type: Scalars['String'];
    url: Scalars['String'];
};
export declare type ErrorObjectInput = {
    columnNumber: Scalars['Int'];
    event: Scalars['String'];
    lineNumber: Scalars['Int'];
    payload?: InputMaybe<Scalars['String']>;
    source: Scalars['String'];
    stackTrace: Array<InputMaybe<StackFrameInput>>;
    timestamp: Scalars['Timestamp'];
    type: Scalars['String'];
    url: Scalars['String'];
};
export declare type MetricInput = {
    category?: InputMaybe<Scalars['String']>;
    group?: InputMaybe<Scalars['String']>;
    name: Scalars['String'];
    session_secure_id: Scalars['String'];
    timestamp: Scalars['Timestamp'];
    type?: InputMaybe<Scalars['Any']>;
    url?: InputMaybe<Scalars['String']>;
    value: Scalars['Float'];
};
export declare type Mutation = {
    __typename?: 'Mutation';
    addSessionFeedback: Scalars['ID'];
    addSessionProperties?: Maybe<Scalars['ID']>;
    addTrackProperties?: Maybe<Scalars['ID']>;
    identifySession?: Maybe<Scalars['ID']>;
    initializeSession?: Maybe<Session>;
    markBackendSetup: Scalars['ID'];
    pushBackendPayload?: Maybe<Scalars['Any']>;
    pushMetrics: Scalars['ID'];
    pushPayload: Scalars['Int'];
};
export declare type MutationAddSessionFeedbackArgs = {
    session_id: Scalars['ID'];
    timestamp: Scalars['Timestamp'];
    user_email?: InputMaybe<Scalars['String']>;
    user_name?: InputMaybe<Scalars['String']>;
    verbatim: Scalars['String'];
};
export declare type MutationAddSessionPropertiesArgs = {
    properties_object?: InputMaybe<Scalars['Any']>;
    session_id: Scalars['ID'];
};
export declare type MutationAddTrackPropertiesArgs = {
    properties_object?: InputMaybe<Scalars['Any']>;
    session_id: Scalars['ID'];
};
export declare type MutationIdentifySessionArgs = {
    session_id: Scalars['ID'];
    user_identifier: Scalars['String'];
    user_object?: InputMaybe<Scalars['Any']>;
};
export declare type MutationInitializeSessionArgs = {
    appVersion?: InputMaybe<Scalars['String']>;
    clientConfig: Scalars['String'];
    clientVersion: Scalars['String'];
    client_id?: InputMaybe<Scalars['String']>;
    enable_recording_network_contents: Scalars['Boolean'];
    enable_strict_privacy: Scalars['Boolean'];
    environment: Scalars['String'];
    fingerprint: Scalars['String'];
    firstloadVersion: Scalars['String'];
    organization_verbose_id: Scalars['String'];
    session_secure_id?: InputMaybe<Scalars['String']>;
};
export declare type MutationMarkBackendSetupArgs = {
    session_secure_id: Scalars['String'];
};
export declare type MutationPushBackendPayloadArgs = {
    errors: Array<InputMaybe<BackendErrorObjectInput>>;
};
export declare type MutationPushMetricsArgs = {
    metrics: Array<InputMaybe<MetricInput>>;
};
export declare type MutationPushPayloadArgs = {
    errors: Array<InputMaybe<ErrorObjectInput>>;
    events: ReplayEventsInput;
    has_session_unloaded?: InputMaybe<Scalars['Boolean']>;
    highlight_logs?: InputMaybe<Scalars['String']>;
    is_beacon?: InputMaybe<Scalars['Boolean']>;
    messages: Scalars['String'];
    resources: Scalars['String'];
    session_id: Scalars['ID'];
};
export declare type Query = {
    __typename?: 'Query';
    ignore?: Maybe<Scalars['Any']>;
};
export declare type QueryIgnoreArgs = {
    id: Scalars['ID'];
};
export declare type ReplayEventInput = {
    _sid: Scalars['Float'];
    data: Scalars['Any'];
    timestamp: Scalars['Float'];
    type: Scalars['Int'];
};
export declare type ReplayEventsInput = {
    events: Array<InputMaybe<ReplayEventInput>>;
};
export declare type Session = {
    __typename?: 'Session';
    id: Scalars['ID'];
    organization_id: Scalars['ID'];
    project_id: Scalars['ID'];
    secure_id: Scalars['String'];
};
export declare type StackFrameInput = {
    args?: InputMaybe<Array<InputMaybe<Scalars['Any']>>>;
    columnNumber?: InputMaybe<Scalars['Int']>;
    fileName?: InputMaybe<Scalars['String']>;
    functionName?: InputMaybe<Scalars['String']>;
    isEval?: InputMaybe<Scalars['Boolean']>;
    isNative?: InputMaybe<Scalars['Boolean']>;
    lineNumber?: InputMaybe<Scalars['Int']>;
    source?: InputMaybe<Scalars['String']>;
};
export declare type PushPayloadMutationVariables = Types.Exact<{
    session_id: Types.Scalars['ID'];
    events: Types.ReplayEventsInput;
    messages: Types.Scalars['String'];
    resources: Types.Scalars['String'];
    errors: Array<Types.InputMaybe<Types.ErrorObjectInput>> | Types.InputMaybe<Types.ErrorObjectInput>;
    is_beacon?: Types.InputMaybe<Types.Scalars['Boolean']>;
    has_session_unloaded?: Types.InputMaybe<Types.Scalars['Boolean']>;
    highlight_logs?: Types.InputMaybe<Types.Scalars['String']>;
}>;
export declare type PushPayloadMutation = {
    __typename?: 'Mutation';
    pushPayload: number;
};
export declare type IdentifySessionMutationVariables = Types.Exact<{
    session_id: Types.Scalars['ID'];
    user_identifier: Types.Scalars['String'];
    user_object?: Types.InputMaybe<Types.Scalars['Any']>;
}>;
export declare type IdentifySessionMutation = {
    __typename?: 'Mutation';
    identifySession?: string | null;
};
export declare type AddSessionPropertiesMutationVariables = Types.Exact<{
    session_id: Types.Scalars['ID'];
    properties_object?: Types.InputMaybe<Types.Scalars['Any']>;
}>;
export declare type AddSessionPropertiesMutation = {
    __typename?: 'Mutation';
    addSessionProperties?: string | null;
};
export declare type PushMetricsMutationVariables = Types.Exact<{
    metrics: Array<Types.InputMaybe<Types.MetricInput>> | Types.InputMaybe<Types.MetricInput>;
}>;
export declare type PushMetricsMutation = {
    __typename?: 'Mutation';
    pushMetrics: string;
};
export declare type AddTrackPropertiesMutationVariables = Types.Exact<{
    session_id: Types.Scalars['ID'];
    properties_object?: Types.InputMaybe<Types.Scalars['Any']>;
}>;
export declare type AddTrackPropertiesMutation = {
    __typename?: 'Mutation';
    addTrackProperties?: string | null;
};
export declare type AddSessionFeedbackMutationVariables = Types.Exact<{
    session_id: Types.Scalars['ID'];
    user_name?: Types.InputMaybe<Types.Scalars['String']>;
    user_email?: Types.InputMaybe<Types.Scalars['String']>;
    verbatim: Types.Scalars['String'];
    timestamp: Types.Scalars['Timestamp'];
}>;
export declare type AddSessionFeedbackMutation = {
    __typename?: 'Mutation';
    addSessionFeedback: string;
};
export declare type InitializeSessionMutationVariables = Types.Exact<{
    organization_verbose_id: Types.Scalars['String'];
    enable_strict_privacy: Types.Scalars['Boolean'];
    enable_recording_network_contents: Types.Scalars['Boolean'];
    clientVersion: Types.Scalars['String'];
    firstloadVersion: Types.Scalars['String'];
    clientConfig: Types.Scalars['String'];
    environment: Types.Scalars['String'];
    id: Types.Scalars['String'];
    appVersion?: Types.InputMaybe<Types.Scalars['String']>;
    session_secure_id?: Types.InputMaybe<Types.Scalars['String']>;
    client_id?: Types.InputMaybe<Types.Scalars['String']>;
}>;
export declare type InitializeSessionMutation = {
    __typename?: 'Mutation';
    initializeSession?: {
        __typename?: 'Session';
        id: string;
        secure_id: string;
        organization_id: string;
        project_id: string;
    } | null;
};
export declare type IgnoreQueryVariables = Types.Exact<{
    id: Types.Scalars['ID'];
}>;
export declare type IgnoreQuery = {
    __typename?: 'Query';
    ignore?: any | null;
};
export declare const PushPayloadDocument: import("graphql").DocumentNode;
export declare const IdentifySessionDocument: import("graphql").DocumentNode;
export declare const AddSessionPropertiesDocument: import("graphql").DocumentNode;
export declare const PushMetricsDocument: import("graphql").DocumentNode;
export declare const AddTrackPropertiesDocument: import("graphql").DocumentNode;
export declare const AddSessionFeedbackDocument: import("graphql").DocumentNode;
export declare const InitializeSessionDocument: import("graphql").DocumentNode;
export declare const IgnoreDocument: import("graphql").DocumentNode;
export declare type SdkFunctionWrapper = <T>(action: (requestHeaders?: Record<string, string>) => Promise<T>, operationName: string, operationType?: string) => Promise<T>;
export declare function getSdk(client: GraphQLClient, withWrapper?: SdkFunctionWrapper): {
    PushPayload(variables: PushPayloadMutationVariables, requestHeaders?: Dom.RequestInit['headers']): Promise<PushPayloadMutation>;
    identifySession(variables: IdentifySessionMutationVariables, requestHeaders?: Dom.RequestInit['headers']): Promise<IdentifySessionMutation>;
    addSessionProperties(variables: AddSessionPropertiesMutationVariables, requestHeaders?: Dom.RequestInit['headers']): Promise<AddSessionPropertiesMutation>;
    pushMetrics(variables: PushMetricsMutationVariables, requestHeaders?: Dom.RequestInit['headers']): Promise<PushMetricsMutation>;
    addTrackProperties(variables: AddTrackPropertiesMutationVariables, requestHeaders?: Dom.RequestInit['headers']): Promise<AddTrackPropertiesMutation>;
    addSessionFeedback(variables: AddSessionFeedbackMutationVariables, requestHeaders?: Dom.RequestInit['headers']): Promise<AddSessionFeedbackMutation>;
    initializeSession(variables: InitializeSessionMutationVariables, requestHeaders?: Dom.RequestInit['headers']): Promise<InitializeSessionMutation>;
    Ignore(variables: IgnoreQueryVariables, requestHeaders?: Dom.RequestInit['headers']): Promise<IgnoreQuery>;
};
export declare type Sdk = ReturnType<typeof getSdk>;
